@@ -1,3 +1,14 @@
+"""
+Helper method for dynamically creating range names, i.e. 'A2:BR34'.
+
+.. currentmodule:: gspread_helpers.range_name.range_name
+
+.. autosummary::
+    :toctree: range_name/
+
+    RangeName
+"""
+
 from __future__ import annotations
 
 __all__ = ["RangeName"]
@@ -43,7 +54,12 @@ class RangeName:
     buffer : int | str, optional
         If you do not want to construct the range name beginning from the letter
         'A' then provide an integer or alphabetical letter that corresponds to the
-        position with which you intend to begin constructing the range name.
+        position with which you intend to begin constructing the range name. When
+        providing an integer, think of that value as meaning how many shifts to the
+        right you want. For instance, if you intend to begin constructing the
+        range name from 'B' then provide '1' as an argument, i.e. one shift
+        rightward. It may be more intuitive, therefore, to provide alphabetical
+        letters as arguments instead of integers!
     source : ('google_sheets', 'excel'), optional
         Default is 'google_sheets'.
     override_row_limit : bool, optional
@@ -74,7 +90,6 @@ class RangeName:
     Below, we override that limitation using the `override_col_limit` argument
     set to `True` and by setting `source` equal to 'excel'.
 
-    >>> from gspread_helpers import RangeName
     >>> rn = RangeName(
     >>>     rows=2, cols=1_048_580, override_col_limit=True, source="excel"
     >>> )
