@@ -1,3 +1,17 @@
+"""
+Configurable constants for controlling column and row limitations.
+
+.. currentmodule:: gspread_helpers.range_name.validations
+
+.. autosummary::
+    :toctree: range_name/
+
+    GOOGLE_SHEETS_ROW_LIMIT     Maximum number of rows for worksheets in Google Sheets.
+    EXCEL_ROW_LIMIT             Maximum number of rows for worksheets in Microsoft Excel.
+    GOOGLE_SHEETS_COL_LIMIT     Maximum number of columns for worksheets in Google Sheets.
+    EXCEL_COL_LIMIT             Maximum number of columns for worksheets in Microsoft Excel.
+"""
+
 from __future__ import annotations
 
 __all__ = [
@@ -13,10 +27,10 @@ from attrs import Attribute
 
 from .exceptions import ColumnLimitExceeded, RowLimitExceeded
 
-GOOGLE_SHEETS_ROW_LIMIT = 10_000_000
-EXCEL_ROW_LIMIT = 1_048_576
-GOOGLE_SHEETS_COL_LIMIT = 18_278
-EXCEL_COL_LIMIT = 16_384
+GOOGLE_SHEETS_ROW_LIMIT: int = 10_000_000
+EXCEL_ROW_LIMIT: int = 1_048_576
+GOOGLE_SHEETS_COL_LIMIT: int = 18_278
+EXCEL_COL_LIMIT: int = 16_384
 
 
 def _validate_buffer_arg(
@@ -26,6 +40,15 @@ def _validate_buffer_arg(
     int, the value must be greater than or equal to zero, and, if str, the value
     must be alphabetical.
 
+    Parameters
+    ----------
+    instance : RangeName
+        RangeName object.
+    attribute : Attribute
+        `attrs.Attribute` object.
+    value : int
+        Parameter to validate.
+
     Raises
     ------
     ValueError : Exception
@@ -57,6 +80,15 @@ def _validate_rows_arg(
     """Validates that the rows argument does not exceed platform limits per
     the source and override_row_limit arguments.
 
+    Parameters
+    ----------
+    instance : RangeName
+        RangeName object.
+    attribute : Attribute
+        `attrs.Attribute` object.
+    value : int
+        Parameter to validate.
+
     Raises
     ------
     RowLimitExceeded : Exception
@@ -87,6 +119,15 @@ def _validate_cols_arg(
     """Validates that the cols argument does not exceed platform limits per
     the source and override_col_limit arguments.
 
+    Parameters
+    ----------
+    instance : RangeName
+        RangeName object.
+    attribute : Attribute
+        `attrs.Attribute` object.
+    value : int
+        Parameter to validate.
+
     Raises
     ------
     ColumnLimitExceeded : Exception
